@@ -804,7 +804,7 @@ def embed_spectra(model, ids_usi_data, vstack_encoded_spectra, output_embedd_fil
     print("Finish spectra embedding, save embedded spectra to " + output_embedd_file + "!")
 
 
-def encode_and_embed_spectra(model, prj, input_file_path, refrence_spectra):
+def encode_and_embed_spectra(model, prj, input_file, refrence_spectra):
     """
 
     :param model: .pkl format embedding model
@@ -815,19 +815,15 @@ def encode_and_embed_spectra(model, prj, input_file_path, refrence_spectra):
     :param use_gpu: bool
     :return: embedded spectra 32d vector
     """
-    input_file_list = os.listdir(input_file_path)
-    if str(input_file_path).endswith("\\"):
-        dir_path = input_file_path
+
+    dirname, filename = os.path.split(os.path.abspath(input_file))
+    if input_file.endswith(".mgf"):
+        output_embedded_file = dirname + "/" + str(filename.strip(".mgf")) + "_embedded.txt"
+    elif input_file.endswith(".mzML"):
+        output_embedded_file = dirname + "/" + str(filename.strip(".mzML")) + "_embedded.txt"
     else:
-        dir_path = input_file_path + "\\"
-    for input_file in input_file_list:
-        if input_file.endswith(".mgf"):
-            output_embedded_file = dir_path + str(input_file.strip(".mgf")) + "_embedded_txt"
-        elif input_file.endswith(".mzML"):
-            output_embedded_file = dir_path + str(input_file.strip(".mzML")) + "_embedded_txt"
-        else:
-            output_embedded_file = dir_path + str(input_file.strip(".json")) + "_embedded_txt"
+        output_embedded_file = dirname + "/" + str(filename.strip(".json")) + "_embedded.txt"
 
-        ids_usi_df, vstack_encoded_spectra = encode_spectra(prj, input_file, refrence_spectra)
-        embed_spectra(model, ids_usi_df, vstack_encoded_spectra, output_embedded_file)
+    ids_usi_df, vstack_encoded_spectra = encode_spectra(prj, input_file, refrence_spectra)
+    embed_spectra(model, ids_usi_df, vstack_encoded_spectra, output_embedded_file)
 
