@@ -38,7 +38,7 @@ class FaissWriteIndex:
         index.add_with_ids(tmp_spectra_vectors.astype('float32'), ids_data)
         self.write_faiss_index(index, output_path)
 
-    def create_index_from_embedded_spectra(self, ids_embedded_spectra_path, ids_save_file, output_path):
+    def create_index_for_embedded_spectra(self, ids_embedded_spectra_path, ids_save_file, output_path):
         """
         Create faiss indexIDMap index
         :param spectra_vectors: spectra embedded data
@@ -58,7 +58,7 @@ class FaissWriteIndex:
 
         for i in range(len(embedded_spectra_file_list)):
             if embedded_spectra_file_list[i].endswith("_embedded.txt"):
-                embedded_spectra_data = pd.read_csv(embedded_spectra_file_list[i], header=True, index=False)
+                embedded_spectra_data = pd.read_csv(embedded_spectra_file_list[i], header=0, index_col=None)
                 ids_data = embedded_spectra_data["ids"].values
                 spectra_vectors = embedded_spectra_data["embedded_spectra"].values
                 tmp_data = []
